/*
 * DMNTK - Decision Model and Notation Toolkit
 *
 * FEEL parser.
 *
 * Copyright 2018-2021 Dariusz Depta Engos Software <dariusz.depta@engos.software>
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

use super::{accept, empty_scope};
use crate::lalr::TokenType::StartTextualExpression;

#[test]
fn abs() {
  let scope = &mut empty_scope();
  accept(
    scope,
    StartTextualExpression,
    "abs(1)",
    r#"
        FunctionInvocation
          Name
            `abs`
          PositionalParameters
            Numeric 1.
      "#,
    false,
  );
}

#[test]
fn not() {
  let scope = &mut empty_scope();
  accept(
    scope,
    StartTextualExpression,
    "not(true)",
    r#"
        FunctionInvocation
          Name
            `not`
          PositionalParameters
            Boolean true
      "#,
    false,
  );
}
